From: Valentin Schneider <vschn...@redhat.com>

The context_tracking.state RCU_DYNTICKS subvariable has been renamed to
RCU_WATCHING, reflect that change in the related helpers.

Note that "watching" is the opposite of "in EQS", so the negation is lifted
out of the helper and into the callsites.

Signed-off-by: Valentin Schneider <vschn...@redhat.com>
Reviewed-by: Frederic Weisbecker <frede...@kernel.org>
Signed-off-by: Neeraj Upadhyay <neeraj.upadh...@kernel.org>
---
 include/linux/context_tracking.h | 12 ++++++++----
 kernel/context_tracking.c        |  6 +++---
 kernel/rcu/tree.c                |  6 +++---
 3 files changed, 14 insertions(+), 10 deletions(-)

diff --git a/kernel/context_tracking.c b/kernel/context_tracking.c
index 00c8f128885a..31c6d0c1b79d 100644
--- a/kernel/context_tracking.c
+++ b/kernel/context_tracking.c
@@ -212,7 +212,7 @@ void noinstr ct_nmi_exit(void)
         * to us!)
         */
        WARN_ON_ONCE(ct_nmi_nesting() <= 0);
-       WARN_ON_ONCE(rcu_dynticks_curr_cpu_in_eqs());
+       WARN_ON_ONCE(!rcu_is_watching_curr_cpu());
 
        /*
         * If the nesting level is not 1, the CPU wasn't RCU-idle, so
@@ -271,7 +271,7 @@ void noinstr ct_nmi_enter(void)
         * to be in the outermost NMI handler that interrupted an RCU-idle
         * period (observation due to Andy Lutomirski).
         */
-       if (rcu_dynticks_curr_cpu_in_eqs()) {
+       if (!rcu_is_watching_curr_cpu()) {
 
                if (!in_nmi())
                        rcu_task_enter();
@@ -281,7 +281,7 @@ void noinstr ct_nmi_enter(void)
                // ... but is watching here.
 
                instrumentation_begin();
-               // instrumentation for the noinstr 
rcu_dynticks_curr_cpu_in_eqs()
+               // instrumentation for the noinstr rcu_is_watching_curr_cpu()
                instrument_atomic_read(&ct->state, sizeof(ct->state));
                // instrumentation for the noinstr ct_kernel_enter_state()
                instrument_atomic_write(&ct->state, sizeof(ct->state));
diff --git a/kernel/rcu/tree.c b/kernel/rcu/tree.c
index 4778c873f4ac..68eca7d3fdd1 100644
--- a/kernel/rcu/tree.c
+++ b/kernel/rcu/tree.c
@@ -601,7 +601,7 @@ void rcu_irq_exit_check_preempt(void)
        RCU_LOCKDEP_WARN(ct_nmi_nesting() !=
                         CT_NESTING_IRQ_NONIDLE,
                         "Bad RCU  nmi_nesting counter\n");
-       RCU_LOCKDEP_WARN(rcu_dynticks_curr_cpu_in_eqs(),
+       RCU_LOCKDEP_WARN(!rcu_is_watching_curr_cpu(),
                         "RCU in extended quiescent state!");
 }
 #endif /* #ifdef CONFIG_PROVE_RCU */
@@ -641,7 +641,7 @@ void __rcu_irq_enter_check_tick(void)
        if (in_nmi())
                return;
 
-       RCU_LOCKDEP_WARN(rcu_dynticks_curr_cpu_in_eqs(),
+       RCU_LOCKDEP_WARN(!rcu_is_watching_curr_cpu(),
                         "Illegal rcu_irq_enter_check_tick() from extended 
quiescent state");
 
        if (!tick_nohz_full_cpu(rdp->cpu) ||
@@ -723,7 +723,7 @@ notrace bool rcu_is_watching(void)
        bool ret;
 
        preempt_disable_notrace();
-       ret = !rcu_dynticks_curr_cpu_in_eqs();
+       ret = rcu_is_watching_curr_cpu();
        preempt_enable_notrace();
        return ret;
 }
diff --git a/include/linux/context_tracking.h b/include/linux/context_tracking.h
index a6c36780cc3b..d53092ffa9db 100644
--- a/include/linux/context_tracking.h
+++ b/include/linux/context_tracking.h
@@ -113,13 +113,17 @@ extern void ct_idle_enter(void);
 extern void ct_idle_exit(void);
 
 /*
  * Is the current CPU in an extended quiescent state?
state)?
+ *
+ * Note that this returns the actual boolean data (watching / not watching),
+ * whereas ct_rcu_watching() returns the RCU_WATCHING subvariable of
+ * context_tracking.state.
  *
  * No ordering, as we are sampling CPU-local information.
  */
-static __always_inline bool rcu_dynticks_curr_cpu_in_eqs(void)
+static __always_inline bool rcu_is_watching_curr_cpu(void)
 {
-       return !(raw_atomic_read(this_cpu_ptr(&context_tracking.state)) & 
CT_RCU_WATCHING);
+       return raw_atomic_read(this_cpu_ptr(&context_tracking.state)) & 
CT_RCU_WATCHING;
 }
 
 /*
@@ -140,7 +144,7 @@ static __always_inline bool warn_rcu_enter(void)
         * lots of the actual reporting also relies on RCU.
         */
        preempt_disable_notrace();
-       if (rcu_dynticks_curr_cpu_in_eqs()) {
+       if (!rcu_is_watching_curr_cpu()) {
                ret = true;
                ct_state_inc(CT_RCU_WATCHING);
        }
@@ -113,13 +113,17 @@ extern void ct_idle_enter(void);
 
 /*
- * Is the current CPU in an extended quiescent state?
+ * Is RCU watching the current CPU (IOW, it is not in an extended quiescent 
state)?
-- 
2.40.1


Reply via email to